ver_mjr = R.Version()$major
ver_mnr = unlist(strsplit(R.Version()$minor,"\\."))[1]
lpath = sprintf("~/AppData/Local/R/win-library/%s.%s",ver_mjr,ver_mnr)
rversion = R.Version()
platform = Sys.info()['sysname']
print(sprintf("R version %s.%s running on %s",ver_mjr,ver_mnr,platform))
if(platform == "Windows") {
   if(!file.exists(lpath)) {
     dir.create(lpath,recursive=TRUE)
   }
   libpath <- c(lpath)
  .libPaths(libpath)
} else {
  libpath <- .libPaths()
  lpath <- .libPaths()
}

source('custom.R')

# load usefull packages
load.libraries(c('stringi','tidyverse'),lpath)
#library(tidyverse)

# read data frame
df <- read_csv(file = "data/realeye.csv")

# split aoi_name variable into two variables by "_"
df <- df %>% 
  separate(aoi_name, sep = "_", into = c("aoi_type", "picture"))


# delete three variables "notes", "aoi_id", and picture
# remove four subjects which were not following instruction 
# replace NAs with 0
df <- df %>% 
  select(-notes, -aoi_id, -picture) %>% 
  filter(ID != "61567" & ID!="64828" & ID!="66001" & ID != "54127")
  
df <- df %>%   
  replace_na(list(aoi_fixation_ttff_ms = 0, aoi_fixation_average_duration_ms = 0, 
                  aoi_fixation_average_total_time_spent_ms = 0, 
                  aoi_fixation_first_fixation_average_duration_ms = 0))

# 
# read data file with additional variables
dq <- read_csv(file = "data/qualtrics.csv")

# join two data frames by ID (subject ID variable)
d <- inner_join(df,dq, by = "ID")


# calculate the NEP (New Ecological Paradigm) score (sum)
# calculate median-split factor for NEP
# factorize aoi_type
# set "neutral" as reference level of aoi_type
# remove row data from NEP
d <- d %>% 
  mutate(NEP = rowSums(select(.,starts_with("Q")))) %>% 
  mutate(NEPsplit = cut(NEP, 2, labels = c("low", "high"))) %>% 
  mutate(aoi_type = factor(aoi_type)) %>% 
  mutate(aoi_type = relevel(aoi_type, ref = "neutral")) %>% 
  select(-starts_with("Q"))


# write the entire data base into RData file 
save(d, file = "data/all_data.Rda")
# or csv file
write_csv(d, path = "data/all_data.csv")

